import { Directionality } from '@angular/cdk/bidi';
import { DoCheck, ElementRef, InjectionToken, Injector, OnDestroy, OnInit } from '@angular/core';
import { FormGroupDirective, NgControl, NgForm, ValidatorFn } from '@angular/forms';
import { ErrorStateMatcher } from '@angular/material/core';
import { NgxPlusifyDateAdapter } from './core/date-adapter';
import { NgxPlusifyDateFormats } from './core/date-formats';
import { NgxDateRange, NgxDateSelectionModelChange } from './date-selection-model';
import { NgxDateFilterFn, NgxPlusifyDatepickerInputBase } from './datepicker-input-base';
import * as i0 from "@angular/core";
/** Parent component that should be wrapped around `MatStartDate` and `MatEndDate`. */
export interface NgxPlusifyDateRangeInputParent<D> {
    id: string;
    min: D | null;
    max: D | null;
    dateFilter: NgxDateFilterFn<D>;
    rangePicker: {
        opened: boolean;
        id: string;
    };
    _startInput: NgxPlusifyDateRangeInputPartBase<D>;
    _endInput: NgxPlusifyDateRangeInputPartBase<D>;
    _groupDisabled: boolean;
    _handleChildValueChange(): void;
    _openDatepicker(): void;
}
/**
 * Used to provide the date range input wrapper component
 * to the parts without circular dependencies.
 */
export declare const NGX_PLUSIFY_DATE_RANGE_INPUT_PARENT: InjectionToken<NgxPlusifyDateRangeInputParent<unknown>>;
/**
 * Base class for the individual inputs that can be projected inside a `mat-date-range-input`.
 */
declare abstract class NgxPlusifyDateRangeInputPartBase<D> extends NgxPlusifyDatepickerInputBase<NgxDateRange<D>> implements OnInit, DoCheck, OnDestroy {
    _rangeInput: NgxPlusifyDateRangeInputParent<D>;
    _elementRef: ElementRef<HTMLInputElement>;
    _defaultErrorStateMatcher: ErrorStateMatcher;
    private _injector;
    _parentForm: NgForm;
    _parentFormGroup: FormGroupDirective;
    private _tracker;
    /** Whether the component is in an error state. */
    get errorState(): boolean;
    set errorState(value: boolean);
    /** An object used to control the error state of the component. */
    get errorStateMatcher(): ErrorStateMatcher;
    set errorStateMatcher(value: ErrorStateMatcher);
    /**
     * Form control bound to this input part.
     * @docs-private
     */
    ngControl: NgControl | null;
    protected abstract _validator: ValidatorFn | null;
    protected abstract _assignValueToModel(value: D | null): void;
    protected abstract _getValueFromModel(modelValue: NgxDateRange<D>): D | null;
    protected readonly _dir: Directionality;
    constructor(_rangeInput: NgxPlusifyDateRangeInputParent<D>, _elementRef: ElementRef<HTMLInputElement>, _defaultErrorStateMatcher: ErrorStateMatcher, _injector: Injector, _parentForm: NgForm, _parentFormGroup: FormGroupDirective, dateAdapter: NgxPlusifyDateAdapter<D>, dateFormats: NgxPlusifyDateFormats);
    ngOnInit(): void;
    ngOnDestroy(): void;
    ngDoCheck(): void;
    updateErrorState(): void;
    /** Gets whether the input is empty. */
    isEmpty(): boolean;
    /** Gets the placeholder of the input. */
    _getPlaceholder(): string;
    /** Focuses the input. */
    focus(): void;
    /** Gets the value that should be used when mirroring the input's size. */
    getMirrorValue(): string;
    /** Handles `input` events on the input element. */
    _onInput(value: string): void;
    /** Opens the datepicker associated with the input. */
    protected _openPopup(): void;
    /** Gets the minimum date from the range input. */
    _getMinDate(): D;
    /** Gets the maximum date from the range input. */
    _getMaxDate(): D;
    /** Gets the date filter function from the range input. */
    protected _getDateFilter(): NgxDateFilterFn<D>;
    protected _parentDisabled(): boolean;
    protected _shouldHandleChangeEvent({ source, }: NgxDateSelectionModelChange<NgxDateRange<D>>): boolean;
    protected _assignValueProgrammatically(value: D | null): void;
    /** return the ARIA accessible name of the input element */
    _getAccessibleName(): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<NgxPlusifyDateRangeInputPartBase<any>, [null, null, null, null, { optional: true; }, { optional: true; }, { optional: true; }, { optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<NgxPlusifyDateRangeInputPartBase<any>, never, never, {}, {}, never, never, true, never>;
}
/** Input for entering the start date in a `mat-date-range-input`. */
export declare class NgxPlusifyStartDate<D> extends NgxPlusifyDateRangeInputPartBase<D> {
    /** Validator that checks that the start date isn't after the end date. */
    private _startValidator;
    constructor(rangeInput: NgxPlusifyDateRangeInputParent<D>, elementRef: ElementRef<HTMLInputElement>, defaultErrorStateMatcher: ErrorStateMatcher, injector: Injector, parentForm: NgForm, parentFormGroup: FormGroupDirective, dateAdapter: NgxPlusifyDateAdapter<D>, dateFormats: NgxPlusifyDateFormats);
    protected _validator: ValidatorFn;
    /** Updates the error state based on the provided error state matcher. */
    updateErrorState(): void;
    protected _getValueFromModel(modelValue: NgxDateRange<D>): D;
    protected _shouldHandleChangeEvent(change: NgxDateSelectionModelChange<NgxDateRange<D>>): boolean;
    protected _assignValueToModel(value: D | null): void;
    protected _formatValue(value: D | null): void;
    _onKeydown(event: KeyboardEvent): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<NgxPlusifyStartDate<any>, [null, null, null, null, { optional: true; }, { optional: true; }, { optional: true; }, { optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<NgxPlusifyStartDate<any>, "input[ngxPlusifyStartDate]", never, { "errorStateMatcher": { "alias": "errorStateMatcher"; "required": false; }; }, { "dateChange": "dateChange"; "dateInput": "dateInput"; }, never, never, true, never>;
}
/** Input for entering the end date in a `mat-date-range-input`. */
export declare class NgxPlusifyEndDate<D> extends NgxPlusifyDateRangeInputPartBase<D> {
    /** Validator that checks that the end date isn't before the start date. */
    private _endValidator;
    constructor(rangeInput: NgxPlusifyDateRangeInputParent<D>, elementRef: ElementRef<HTMLInputElement>, defaultErrorStateMatcher: ErrorStateMatcher, injector: Injector, parentForm: NgForm, parentFormGroup: FormGroupDirective, dateAdapter: NgxPlusifyDateAdapter<D>, dateFormats: NgxPlusifyDateFormats);
    protected _validator: ValidatorFn;
    /** Updates the error state based on the provided error state matcher. */
    updateErrorState(): void;
    protected _getValueFromModel(modelValue: NgxDateRange<D>): D;
    protected _shouldHandleChangeEvent(change: NgxDateSelectionModelChange<NgxDateRange<D>>): boolean;
    protected _assignValueToModel(value: D | null): void;
    _onKeydown(event: KeyboardEvent): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<NgxPlusifyEndDate<any>, [null, null, null, null, { optional: true; }, { optional: true; }, { optional: true; }, { optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<NgxPlusifyEndDate<any>, "input[ngxPlusifyEndDate]", never, { "errorStateMatcher": { "alias": "errorStateMatcher"; "required": false; }; }, { "dateChange": "dateChange"; "dateInput": "dateInput"; }, never, never, true, never>;
}
export {};
